optmanage.option
================

.. automodule:: optmanage.option

Option
------

.. autoclass:: optmanage.option.Option
    :show-inheritance:
    :members:
    :special-members: __new__, __set_name__, __set__, __get__

TYPE_CHECKING
-------------

.. autodata:: optmanage.option.TYPE_CHECKING

Validator
---------

.. autoclass:: optmanage.option.Validator
    :show-inheritance:
    :members:

ValueT
------

.. autodata:: optmanage.option.ValueT

ValueT_contra
-------------

.. autodata:: optmanage.option.ValueT_contra
